pub struct KeyEventState(/* private fields */);Expand description
Represents extra state about the key event.
Note: This state can only be read if
KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with
PushKeyboardEnhancementFlags.
Implementations
Sourceimpl KeyEventState
impl KeyEventState
Sourcepub const KEYPAD: KeyEventState
pub const KEYPAD: KeyEventState
The key event origins from the keypad.
Sourcepub const CAPS_LOCK: KeyEventState
pub const CAPS_LOCK: KeyEventState
Caps Lock was enabled for this key event.
Note: this is set for the initial press of Caps Lock itself.
Sourcepub const NUM_LOCK: KeyEventState
pub const NUM_LOCK: KeyEventState
Num Lock was enabled for this key event.
Note: this is set for the initial press of Num Lock itself.
pub const NONE: KeyEventState
Sourceimpl KeyEventState
impl KeyEventState
Sourcepub const fn empty() -> KeyEventState
pub const fn empty() -> KeyEventState
Get a flags value with all bits unset.
Sourcepub const fn all() -> KeyEventState
pub const fn all() -> KeyEventState
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<KeyEventState>
pub const fn from_bits(bits: u8) -> Option<KeyEventState>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> KeyEventState
pub const fn from_bits_truncate(bits: u8) -> KeyEventState
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> KeyEventState
pub const fn from_bits_retain(bits: u8) -> KeyEventState
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<KeyEventState>
pub fn from_name(name: &str) -> Option<KeyEventState>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: KeyEventState) -> bool
pub const fn intersects(&self, other: KeyEventState) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: KeyEventState) -> bool
pub const fn contains(&self, other: KeyEventState) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: KeyEventState)
pub fn insert(&mut self, other: KeyEventState)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: KeyEventState)
pub fn remove(&mut self, other: KeyEventState)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: KeyEventState)
pub fn toggle(&mut self, other: KeyEventState)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: KeyEventState, value: bool)
pub fn set(&mut self, other: KeyEventState, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: KeyEventState) -> KeyEventState
pub const fn intersection(self, other: KeyEventState) -> KeyEventState
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: KeyEventState) -> KeyEventState
pub const fn union(self, other: KeyEventState) -> KeyEventState
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: KeyEventState) -> KeyEventState
pub const fn difference(self, other: KeyEventState) -> KeyEventState
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: KeyEventState) -> KeyEventState
pub const fn symmetric_difference(self, other: KeyEventState) -> KeyEventState
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> KeyEventState
pub const fn complement(self) -> KeyEventState
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl KeyEventState
impl KeyEventState
Sourcepub const fn iter(&self) -> Iter<KeyEventState>
pub const fn iter(&self) -> Iter<KeyEventState>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<KeyEventState>
pub const fn iter_names(&self) -> IterNames<KeyEventState>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.