pub fn read() -> Option<Event>Expand description
Get an Event. When raw mode is disabled, the input will only be registered after enter is pressed. Call enable_raw_mode() at the beginning of the program to avoid having to press enter
pub fn read() -> Option<Event>Get an Event. When raw mode is disabled, the input will only be registered after enter is pressed. Call enable_raw_mode() at the beginning of the program to avoid having to press enter